@@ -7,7 +7,7 @@
  *           1.0.0 (OGC Document 05-008c1)
  *           1.1.0 (OGC document 06-121r3)
  *
- * Author:   Tom Kralidis (tomkralidis@hotmail.com)
+ * Author:   Tom Kralidis (tomkralidis@gmail.com)
  *
  ******************************************************************************
  * Copyright (c) 2006, Tom Kralidis
@@ -56,13 +56,17 @@
  *
  * @param map mapObj used to fetch WEB/METADATA
  * @param servicetype the OWS type
- * @param version the version of the OWS
+ * @param supported_versions the supported version(s) of the OWS
  *
  * @return psRootNode xmlNodePtr of XML construct
  *
  */
 
-xmlNodePtr msOWSCommonServiceIdentification(xmlNsPtr psNsOws, mapObj *map, const char *servicetype, const char *version, const char *namespaces)
+xmlNodePtr msOWSCommonServiceIdentification(xmlNsPtr psNsOws, mapObj *map,
+                                            const char *servicetype,
+                                            const char *supported_versions,
+                                            const char *namespaces,
+                                            const char *validated_language)
 {
   const char *value    = NULL;
 
@@ -77,26 +81,26 @@ xmlNodePtr msOWSCommonServiceIdentification(xmlNsPtr psNsOws, mapObj *map, const
 
   /* add child elements */
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "title");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "title", validated_language);
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "Title", BAD_CAST value);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "Title", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_title\" missing for ows:Title"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "abstract");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "abstract", validated_language);
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "Abstract", BAD_CAST value);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "Abstract", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_abstract\" was missing for ows:Abstract"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "keywordlist");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "keywordlist", validated_language);
 
   if (value) {
-    psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "Keywords", NULL);
+    psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "Keywords", NULL);
     msLibXml2GenerateList(psNode, psNsOws, "Keyword", value, ',');
   }
 
@@ -104,23 +108,23 @@ xmlNodePtr msOWSCommonServiceIdentification(xmlNsPtr psNsOws, mapObj *map, const
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_keywordlist\" was missing for ows:KeywordList"));
   }
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "ServiceType", BAD_CAST servicetype);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "ServiceType", BAD_CAST servicetype);
 
   xmlNewProp(psNode, BAD_CAST "codeSpace", BAD_CAST MS_OWSCOMMON_OGC_CODESPACE);
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "ServiceTypeVersion", BAD_CAST version);
+  msLibXml2GenerateList(psRootNode, psNsOws, "ServiceTypeVersion", supported_versions, ',');
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "fees");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "fees", validated_language);
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "Fees", BAD_CAST value);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "Fees", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_fees\" was missing for ows:Fees"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "accessconstraints");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "accessconstraints", validated_language);
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "AccessConstraints", BAD_CAST value);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "AccessConstraints", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_accessconstraints\" was missing for ows:AccessConstraints"));
@@ -145,7 +149,8 @@ xmlNodePtr msOWSCommonServiceIdentification(xmlNsPtr psNsOws, mapObj *map, const
  */
 
 xmlNodePtr msOWSCommonServiceProvider(xmlNsPtr psNsOws, xmlNsPtr psNsXLink,
-                                      mapObj *map, const char *namespaces)
+                                      mapObj *map, const char *namespaces,
+                                      const char *validated_language)
 {
   const char *value = NULL;
 
@@ -162,19 +167,19 @@ xmlNodePtr msOWSCommonServiceProvider(xmlNsPtr psNsOws, xmlNsPtr psNsXLink,
 
   /* add child elements */
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactorganization");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactorganization", validated_language);
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "ProviderName", BAD_CAST value);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "ProviderName", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Mandatory metadata \"ows_contactorganization\" was missing for ows:ProviderName"));
   }
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "ProviderSite", NULL);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "ProviderSite", NULL);
 
   xmlNewNsProp(psNode, psNsXLink, BAD_CAST "type", BAD_CAST "simple");
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "service_onlineresource");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "service_onlineresource", validated_language);
 
   xmlNewNsProp(psNode, psNsXLink, BAD_CAST "href", BAD_CAST value);
 
@@ -182,99 +187,99 @@ xmlNodePtr msOWSCommonServiceProvider(xmlNsPtr psNsOws, xmlNsPtr psNsXLink,
     xmlAddSibling(psNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_service_onlineresource\" was missing for ows:ProviderSite/@xlink:href"));
   }
 
-  psNode = xmlNewChild(psRootNode, psNsOws, BAD_CAST "ServiceContact", NULL);
+  psNode = xmlNewTextChild(psRootNode, psNsOws, BAD_CAST "ServiceContact", NULL);
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactperson");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactperson", validated_language);
 
-  psSubNode = xmlNewChild(psNode, psNsOws, BAD_CAST "IndividualName", BAD_CAST  value);
+  psSubNode = xmlNewTextChild(psNode, psNsOws, BAD_CAST "IndividualName", BAD_CAST  value);
 
   if (!value) {
     xmlAddSibling(psSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_contactperson\" was missing for ows:IndividualName"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactposition");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactposition", validated_language);
 
-  psSubNode = xmlNewChild(psNode, psNsOws, BAD_CAST "PositionName", BAD_CAST value);
+  psSubNode = xmlNewTextChild(psNode, psNsOws, BAD_CAST "PositionName", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_contactposition\" was missing for ows:PositionName"));
   }
 
-  psSubNode = xmlNewChild(psNode, psNsOws, BAD_CAST "ContactInfo", NULL);
+  psSubNode = xmlNewTextChild(psNode, psNsOws, BAD_CAST "ContactInfo", NULL);
 
-  psSubSubNode = xmlNewChild(psSubNode, psNsOws, BAD_CAST "Phone", NULL);
+  psSubSubNode = xmlNewTextChild(psSubNode, psNsOws, BAD_CAST "Phone", NULL);
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactvoicetelephone");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactvoicetelephone", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "Voice", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "Voice", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_contactvoicetelephone\" was missing for ows:Voice"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactfacsimiletelephone");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactfacsimiletelephone", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "Facsimile", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "Facsimile", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_contactfacsimiletelephone\" was missing for ows:Facsimile"));
   }
 
-  psSubSubNode = xmlNewChild(psSubNode, psNsOws, BAD_CAST "Address", NULL);
+  psSubSubNode = xmlNewTextChild(psSubNode, psNsOws, BAD_CAST "Address", NULL);
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "address");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "address", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "DeliveryPoint", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "DeliveryPoint", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_address\" was missing for ows:DeliveryPoint"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "city");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "city", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "City", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "City", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_city\" was missing for ows:City"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "stateorprovince");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "stateorprovince", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "AdministrativeArea", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "AdministrativeArea", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_stateorprovince\" was missing for ows:AdministrativeArea"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "postcode");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "postcode", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "PostalCode", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "PostalCode", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_postcode\" was missing for ows:PostalCode"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "country");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "country", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "Country", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "Country", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_country\" was missing for ows:Country"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactelectronicmailaddress");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactelectronicmailaddress", validated_language);
 
-  psSubSubSubNode = xmlNewChild(psSubSubNode, psNsOws, BAD_CAST "ElectronicMailAddress", BAD_CAST value);
+  psSubSubSubNode = xmlNewTextChild(psSubSubNode, psNsOws, BAD_CAST "ElectronicMailAddress", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_contactelectronicmailaddress\" was missing for ows:ElectronicMailAddress"));
   }
 
-  psSubSubNode = xmlNewChild(psSubNode, psNsOws, BAD_CAST "OnlineResource", NULL);
+  psSubSubNode = xmlNewTextChild(psSubNode, psNsOws, BAD_CAST "OnlineResource", NULL);
 
   xmlNewNsProp(psSubSubNode, psNsXLink, BAD_CAST "type", BAD_CAST "simple");
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "service_onlineresource");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "service_onlineresource", validated_language);
 
   xmlNewNsProp(psSubSubNode, psNsXLink, BAD_CAST "href", BAD_CAST value);
 
@@ -282,25 +287,25 @@ xmlNodePtr msOWSCommonServiceProvider(xmlNsPtr psNsOws, xmlNsPtr psNsXLink,
     xmlAddSibling(psSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_service_onlineresource\" was missing for ows:OnlineResource/@xlink:href"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "hoursofservice");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "hoursofservice", validated_language);
 
-  psSubSubNode = xmlNewChild(psSubNode, psNsOws, BAD_CAST "HoursOfService", BAD_CAST value);
+  psSubSubNode = xmlNewTextChild(psSubNode, psNsOws, BAD_CAST "HoursOfService", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_hoursofservice\" was missing for ows:HoursOfService"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "contactinstructions");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "contactinstructions", validated_language);
 
-  psSubSubNode = xmlNewChild(psSubNode, psNsOws, BAD_CAST "ContactInstructions", BAD_CAST value);
+  psSubSubNode = xmlNewTextChild(psSubNode, psNsOws, BAD_CAST "ContactInstructions", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_contactinstructions\" was missing for ows:ContactInstructions"));
   }
 
-  value = msOWSLookupMetadata(&(map->web.metadata), namespaces, "role");
+  value = msOWSLookupMetadataWithLanguage(&(map->web.metadata), namespaces, "role", validated_language);
 
-  psSubNode = xmlNewChild(psNode, psNsOws, BAD_CAST "Role", BAD_CAST value);
+  psSubNode = xmlNewTextChild(psNode, psNsOws, BAD_CAST "Role", BAD_CAST value);
 
   if (!value) {
     xmlAddSibling(psSubNode, xmlNewComment(BAD_CAST "WARNING: Optional metadata \"ows_role\" was missing for ows:Role"));
@@ -484,7 +489,7 @@ xmlNodePtr msOWSCommonExceptionReport(xmlNsPtr psNsOws, int ows_version, const c
   }
 
   if (ExceptionText != NULL) {
-    xmlNewChild(psMainNode, NULL, BAD_CAST "ExceptionText", BAD_CAST ExceptionText);
+    xmlNewTextChild(psMainNode, NULL, BAD_CAST "ExceptionText", BAD_CAST ExceptionText);
   }
 
   free(xsi_schemaLocation);
@@ -615,21 +620,6 @@ int _validateNamespace(xmlNsPtr psNsOws)
     return MS_FAILURE;
 }
 
-xmlNodePtr msOWSCommonxmlNewChildEncoded( xmlNodePtr psParent, xmlNsPtr psNs, const char* name,
-    const char *content, const char *encoding)
-{
-  char *encoded = NULL;
-  xmlNodePtr psNode;
-
-  if (encoding && content) {
-    encoded = msGetEncodedString(content, encoding);
-    psNode =  xmlNewChild(psParent, psNs, BAD_CAST name, BAD_CAST encoded);
-    msFree(encoded);
-    return psNode;
-  } else
-    return xmlNewChild(psParent, psNs, BAD_CAST name, BAD_CAST content);
-}
-
 /*
  * Valid an xml string against an XML schema
  * Inpired from: http://xml.developpez.com/sources/?page=validation#validate_XSD_CppCLI_2
@@ -650,11 +640,65 @@ int msOWSSchemaValidation(const char* xml_schema, const char* xml)
   schema = NULL;
   ret = -1;
 
-  /* Open XML Schema File */
-  ctxt = xmlSchemaNewParserCtxt(xml_schema);
-  /*
-  else ctxt = xmlSchemaNewMemParserCtxt(xml_schema);
-  */
+  /* To valide WFS 2.0 requests, we might need to explicitely import */
+  /* GML and FES 2.0 */
+  if( strlen(xml_schema) > strlen(MS_OWSCOMMON_WFS_20_SCHEMA_LOCATION) &&
+      strcmp(xml_schema + strlen(xml_schema) -
+            strlen(MS_OWSCOMMON_WFS_20_SCHEMA_LOCATION), MS_OWSCOMMON_WFS_20_SCHEMA_LOCATION) == 0 )
+  {
+    char szInMemSchema[2048];
+    char szBaseLocation[256];
+
+    strncpy(szBaseLocation, xml_schema, strlen(xml_schema) - strlen(MS_OWSCOMMON_WFS_20_SCHEMA_LOCATION));
+    szBaseLocation[strlen(xml_schema) - strlen(MS_OWSCOMMON_WFS_20_SCHEMA_LOCATION)] = '\0';
+
+    strcpy(szInMemSchema, "<schema elementFormDefault=\"qualified\" version=\"1.0.0\" "
+                          "xmlns=\"http://www.w3.org/2001/XMLSchema\">\n");
+
+    sprintf(szInMemSchema + strlen(szInMemSchema),
+            "<import namespace=\"%s\" schemaLocation=\"%s\" />\n",
+            MS_OWSCOMMON_WFS_20_NAMESPACE_URI, xml_schema);
+
+    if( strstr(xml, MS_OWSCOMMON_FES_20_NAMESPACE_URI) != NULL )
+    {
+        sprintf(szInMemSchema + strlen(szInMemSchema),
+                "<import namespace=\"%s\" schemaLocation=\"%s%s\" />\n",
+                MS_OWSCOMMON_FES_20_NAMESPACE_URI, szBaseLocation, MS_OWSCOMMON_FES_20_SCHEMA_LOCATION);
+    }
+
+    if( strstr(xml, MS_OWSCOMMON_GML_32_NAMESPACE_URI) != NULL )
+    {
+        sprintf(szInMemSchema + strlen(szInMemSchema),
+                "<import namespace=\"%s\" schemaLocation=\"%s%s\" />\n",
+                MS_OWSCOMMON_GML_32_NAMESPACE_URI, szBaseLocation, MS_OWSCOMMON_GML_321_SCHEMA_LOCATION);
+    }
+    else if( strstr(xml, MS_OWSCOMMON_GML_NAMESPACE_URI) != NULL )
+    {
+        if( strstr(xml, MS_OWSCOMMON_GML_212_SCHEMA_LOCATION) != NULL )
+        {
+            sprintf(szInMemSchema + strlen(szInMemSchema),
+                    "<import namespace=\"%s\" schemaLocation=\"%s%s\" />\n",
+                    MS_OWSCOMMON_GML_NAMESPACE_URI, szBaseLocation, MS_OWSCOMMON_GML_212_SCHEMA_LOCATION);
+        }
+        else if( strstr(xml, MS_OWSCOMMON_GML_311_SCHEMA_LOCATION) != NULL )
+        {
+            sprintf(szInMemSchema + strlen(szInMemSchema),
+                    "<import namespace=\"%s\" schemaLocation=\"%s%s\" />\n",
+                    MS_OWSCOMMON_GML_NAMESPACE_URI, szBaseLocation, MS_OWSCOMMON_GML_311_SCHEMA_LOCATION);
+        }
+    }
+
+    strcat(szInMemSchema, "</schema>\n");
+    /*fprintf(stderr, "%s\n", szInMemSchema);*/
+
+    ctxt = xmlSchemaNewMemParserCtxt(szInMemSchema, strlen(szInMemSchema));
+  }
+  else
+  {
+    /* Open XML Schema File */
+    ctxt = xmlSchemaNewParserCtxt(xml_schema);
+  }
+
   /*
   xmlSchemaSetParserErrors(ctxt,
                            (xmlSchemaValidityErrorFunc) libxml2_callback,
@@ -710,7 +754,7 @@ int msOWSSchemaValidation(const char* xml_schema, const char* xml)
  *
  */
 
-int msOWSCommonNegotiateVersion(int requested_version, int supported_versions[], int num_supported_versions)
+int msOWSCommonNegotiateVersion(int requested_version, const int supported_versions[], int num_supported_versions)
 {
   int i;
 
