@@ -43,6 +43,8 @@
 #include "mapio.h"
 #include "maptime.h"
 
+#include "cpl_conv.h"
+
 #ifndef WIN32
 #include <signal.h>
 #endif
@@ -162,6 +164,16 @@ int main(int argc, char *argv[])
   if(msGetGlobalDebugLevel() >= MS_DEBUGLEVEL_TUNING)
     msGettimeofday(&execstarttime, NULL);
 
+  /* push high-value ENV vars into the CPL global config - primarily for IIS/FastCGI */
+  const char* const apszEnvVars[] = { 
+    "CURL_CA_BUNDLE", "MS_MAPFILE", "MS_MAP_NO_PATH", "MS_MAP_PATTERN", "MS_MAP_ENV_PATTERN",
+    "MS_MAP_BAD_PATTERN", "MS_MAP_ENV_BAD_PATTERN",
+     NULL /* guard */ };
+  for( int i = 0; apszEnvVars[i] != NULL; ++i ) {
+    const char* value = getenv(apszEnvVars[i]);
+    if(value) CPLSetConfigOption(apszEnvVars[i], value);
+  }
+
   /* -------------------------------------------------------------------- */
   /*      Process arguments.  In normal use as a cgi-bin there are no     */
   /*      commandline switches, but we provide a few for test/debug       */
