@@ -39,9 +39,7 @@
 #include "mapcopy.h"
 #include "mapows.h"
 
-#if defined(USE_OGR) || defined(USE_GDAL)
 #include "gdal.h"
-#endif
 
 #if defined(_WIN32) && !defined(__CYGWIN__)
 # include <windows.h>
@@ -75,21 +73,21 @@ int msScaleInBounds(double scale, double minscale, double maxscale)
 /*
 ** Helper functions to convert from strings to other types or objects.
 */
-static int bindIntegerAttribute(int *attribute, char *value)
+static int bindIntegerAttribute(int *attribute, const char *value)
 {
   if(!value || strlen(value) == 0) return MS_FAILURE;
   *attribute = MS_NINT(atof(value)); /*use atof instead of atoi as a fix for bug 2394*/
   return MS_SUCCESS;
 }
 
-static int bindDoubleAttribute(double *attribute, char *value)
+static int bindDoubleAttribute(double *attribute, const char *value)
 {
   if(!value || strlen(value) == 0) return MS_FAILURE;
   *attribute = atof(value);
   return MS_SUCCESS;
 }
 
-static int bindColorAttribute(colorObj *attribute, char *value)
+static int bindColorAttribute(colorObj *attribute, const char *value)
 {
   int len;
 
@@ -136,8 +134,10 @@ static int bindColorAttribute(colorObj *attribute, char *value)
 
 static void bindStyle(layerObj *layer, shapeObj *shape, styleObj *style, int drawmode)
 {
+  int applyOpacity = MS_FALSE;
   assert(MS_DRAW_FEATURES(drawmode));
   if(style->numbindings > 0) {
+    applyOpacity = MS_TRUE;
     if(style->bindings[MS_STYLE_BINDING_SYMBOL].index != -1) {
       style->symbol = msGetSymbolIndex(&(layer->map->symbolset), shape->values[style->bindings[MS_STYLE_BINDING_SYMBOL].index], MS_TRUE);
       if(style->symbol == -1) style->symbol = 0; /* a reasonable default (perhaps should throw an error?) */
@@ -186,19 +186,70 @@ static void bindStyle(layerObj *layer, shapeObj *shape, styleObj *style, int dra
       style->polaroffsetangle = 0;
       bindDoubleAttribute(&style->polaroffsetangle, shape->values[style->bindings[MS_STYLE_BINDING_POLAROFFSET_ANGLE].index]);
     }
-    if(style->bindings[MS_STYLE_BINDING_OUTLINEWIDTH].index != -1) {
-      style->outlinewidth = 1;
-      bindDoubleAttribute(&style->outlinewidth, shape->values[style->bindings[MS_STYLE_BINDING_OUTLINEWIDTH].index]);
+  }
+  if (style->nexprbindings > 0)
+  {
+    applyOpacity = MS_TRUE;
+    if (style->exprBindings[MS_STYLE_BINDING_OFFSET_X].type == MS_EXPRESSION)
+    {
+      style->offsetx = msEvalDoubleExpression(
+          &(style->exprBindings[MS_STYLE_BINDING_OFFSET_X]),
+          shape);
     }
-    if(style->opacity < 100 || style->color.alpha != 255 ) {
-      int alpha;
-      alpha = MS_NINT(style->opacity*2.55);
-      style->color.alpha = alpha;
-      style->outlinecolor.alpha = alpha;
-      style->backgroundcolor.alpha = alpha;
-      style->mincolor.alpha = alpha;
-      style->maxcolor.alpha = alpha;
+    if (style->exprBindings[MS_STYLE_BINDING_OFFSET_Y].type == MS_EXPRESSION)
+    {
+      style->offsety = msEvalDoubleExpression(
+          &(style->exprBindings[MS_STYLE_BINDING_OFFSET_Y]),
+          shape);
     }
+    if (style->exprBindings[MS_STYLE_BINDING_ANGLE].type == MS_EXPRESSION)
+    {
+      style->angle = msEvalDoubleExpression(
+          &(style->exprBindings[MS_STYLE_BINDING_ANGLE]),
+          shape);
+    }
+    if (style->exprBindings[MS_STYLE_BINDING_SIZE].type == MS_EXPRESSION)
+    {
+      style->size = msEvalDoubleExpression(
+          &(style->exprBindings[MS_STYLE_BINDING_SIZE]),
+          shape);
+    }
+    if (style->exprBindings[MS_STYLE_BINDING_WIDTH].type == MS_EXPRESSION)
+    {
+      style->width = msEvalDoubleExpression(
+          &(style->exprBindings[MS_STYLE_BINDING_WIDTH]),
+          shape);
+    }
+    if (style->exprBindings[MS_STYLE_BINDING_OPACITY].type == MS_EXPRESSION)
+    {
+      style->opacity = 100 * msEvalDoubleExpression(
+          &(style->exprBindings[MS_STYLE_BINDING_OPACITY]),
+          shape);
+    }
+    if (style->exprBindings[MS_STYLE_BINDING_OUTLINECOLOR].type == MS_EXPRESSION)
+    {
+      char* txt = msEvalTextExpression(
+            &(style->exprBindings[MS_STYLE_BINDING_OUTLINECOLOR]), shape);
+      bindColorAttribute(&style->outlinecolor, txt);
+      msFree(txt);
+    }
+    if (style->exprBindings[MS_STYLE_BINDING_COLOR].type == MS_EXPRESSION)
+    {
+      char* txt = msEvalTextExpression(
+            &(style->exprBindings[MS_STYLE_BINDING_COLOR]), shape);
+      bindColorAttribute(&style->color, txt);
+      msFree(txt);
+    }
+  }
+
+  if(applyOpacity == MS_TRUE && (style->opacity < 100 || style->color.alpha != 255) ) {
+    int alpha;
+    alpha = MS_NINT(style->opacity*2.55);
+    style->color.alpha = alpha;
+    style->outlinecolor.alpha = alpha;
+    style->backgroundcolor.alpha = alpha;
+    style->mincolor.alpha = alpha;
+    style->maxcolor.alpha = alpha;
   }
 }
 
@@ -253,6 +304,34 @@ static void bindLabel(layerObj *layer, shapeObj *shape, labelObj *label, int dra
       bindIntegerAttribute(&label->shadowsizey, shape->values[label->bindings[MS_LABEL_BINDING_SHADOWSIZEY].index]);
     }
 
+    if(label->bindings[MS_LABEL_BINDING_OFFSET_X].index != -1) {
+      label->offsetx = 0;
+      bindIntegerAttribute(&label->offsetx, shape->values[label->bindings[MS_LABEL_BINDING_OFFSET_X].index]);
+    }
+
+    if(label->bindings[MS_LABEL_BINDING_OFFSET_Y].index != -1) {
+      label->offsety = 0;
+      bindIntegerAttribute(&label->offsety, shape->values[label->bindings[MS_LABEL_BINDING_OFFSET_Y].index]);
+    }
+
+    if(label->bindings[MS_LABEL_BINDING_ALIGN].index != -1) {
+      int tmpAlign = 0;
+      bindIntegerAttribute(&tmpAlign, shape->values[label->bindings[MS_LABEL_BINDING_ALIGN].index]);
+      if(tmpAlign != 0) { /* is this test sufficient? */
+        label->align = tmpAlign;
+      } else { /* Integer binding failed, look for strings like cc, ul, lr, etc... */
+        if(strlen(shape->values[label->bindings[MS_LABEL_BINDING_ALIGN].index]) >= 4) {
+          char *va = shape->values[label->bindings[MS_LABEL_BINDING_ALIGN].index];
+          if(!strncasecmp(va,"center",5))
+            label->align = MS_ALIGN_CENTER;
+          else if(!strncasecmp(va,"left",4))
+            label->align = MS_ALIGN_LEFT;
+          else if(!strncasecmp(va,"right",5))
+            label->align = MS_ALIGN_RIGHT;
+        }
+      }
+    }
+
     if(label->bindings[MS_LABEL_BINDING_POSITION].index != -1) {
       int tmpPosition = 0;
       bindIntegerAttribute(&tmpPosition, shape->values[label->bindings[MS_LABEL_BINDING_POSITION].index]);
@@ -283,6 +362,35 @@ static void bindLabel(layerObj *layer, shapeObj *shape, labelObj *label, int dra
       }
     }
   }
+  if (label->nexprbindings > 0)
+  {
+    if (label->exprBindings[MS_LABEL_BINDING_ANGLE].type == MS_EXPRESSION)
+    {
+      label->angle = msEvalDoubleExpression(
+          &(label->exprBindings[MS_LABEL_BINDING_ANGLE]),
+          shape);
+    }
+    if (label->exprBindings[MS_LABEL_BINDING_SIZE].type == MS_EXPRESSION)
+    {
+      label->size = msEvalDoubleExpression(
+          &(label->exprBindings[MS_LABEL_BINDING_SIZE]),
+          shape);
+    }
+    if (label->exprBindings[MS_LABEL_BINDING_COLOR].type == MS_EXPRESSION)
+    {
+      char* txt = msEvalTextExpression(
+            &(label->exprBindings[MS_LABEL_BINDING_COLOR]), shape);
+      bindColorAttribute(&label->color, txt);
+      msFree(txt);
+    }
+    if (label->exprBindings[MS_LABEL_BINDING_OUTLINECOLOR].type == MS_EXPRESSION)
+    {
+      char* txt = msEvalTextExpression(
+            &(label->exprBindings[MS_LABEL_BINDING_OUTLINECOLOR]), shape);
+      bindColorAttribute(&label->outlinecolor, txt);
+      msFree(txt);
+    }
+  }
 }
 
 /*
@@ -581,14 +689,23 @@ int *msAllocateValidClassGroups(layerObj *lp, int *nclasses)
 }
 
 int msShapeGetClass(layerObj *layer, mapObj *map, shapeObj *shape, int *classgroup, int numclasses)
+{
+  return msShapeGetNextClass(-1, layer, map, shape, classgroup, numclasses);
+}
+
+int msShapeGetNextClass(int currentclass, layerObj *layer, mapObj *map,
+    shapeObj *shape, int *classgroup, int numclasses)
 {
   int i, iclass;
 
+  if (currentclass < 0)
+    currentclass = -1;
+
   if (layer->numclasses > 0) {
     if (classgroup == NULL || numclasses <=0)
       numclasses = layer->numclasses;
 
-    for(i=0; i<numclasses; i++) {
+    for(i=currentclass+1; i<numclasses; i++) {
       if (classgroup)
         iclass = classgroup[i];
       else
@@ -613,7 +730,18 @@ int msShapeGetClass(layerObj *layer, mapObj *map, shapeObj *shape, int *classgro
       }
 
       if(layer->class[iclass]->status != MS_DELETE && msEvalExpression(layer, shape, &(layer->class[iclass]->expression), layer->classitemindex) == MS_TRUE)
-        return(iclass);
+      {
+        if (layer->class[iclass]->isfallback && currentclass != -1)
+        {
+          // Class is not applicable if it is flagged as fallback (<ElseFilter/> tag in SLD)
+          // but other classes have been applied before.
+          return -1;
+        }
+        else
+        {
+          return(iclass);
+        }
+      }
     }
   }
 
@@ -699,6 +827,27 @@ char *msEvalTextExpression(expressionObj *expr, shapeObj *shape)
     return msEvalTextExpressionInternal(expr, shape, MS_FALSE);
 }
 
+double msEvalDoubleExpression(expressionObj *expression, shapeObj *shape)
+{
+  double value;
+  int status;
+  parseObj p;
+  p.shape = shape;
+  p.expr = expression;
+  p.expr->curtoken = p.expr->tokens; /* reset */
+  p.type = MS_PARSE_TYPE_STRING;
+  status = yyparse(&p);
+  if (status != 0) {
+    msSetError(MS_PARSEERR, "Failed to parse expression: %s",
+        "bindStyle", expression->string);
+    value = 0.0;
+  } else {
+    value = atof(p.result.strval);
+    msFree(p.result.strval);
+  }
+  return value;
+}
+
 char* msShapeGetLabelAnnotation(layerObj *layer, shapeObj *shape, labelObj *lbl) {
   assert(shape && lbl);
   if(lbl->text.string) {
@@ -834,14 +983,13 @@ int msSaveImage(mapObj *map, imageObj *img, const char *filename)
 {
   int nReturnVal = MS_FAILURE;
   char szPath[MS_MAXPATHLEN];
-  struct mstimeval starttime, endtime;
+  struct mstimeval starttime={0}, endtime={0};
 
   if(map && map->debug >= MS_DEBUGLEVEL_TUNING) {
     msGettimeofday(&starttime, NULL);
   }
 
   if (img) {
-#ifdef USE_GDAL
     if( MS_DRIVER_GDAL(img->format) ) {
       if (map != NULL && filename != NULL )
         nReturnVal = msSaveImageGDAL(map, img,
@@ -850,7 +998,6 @@ int msSaveImage(mapObj *map, imageObj *img, const char *filename)
       else
         nReturnVal = msSaveImageGDAL(map, img, filename);
     } else
-#endif
 
       if (MS_RENDERER_PLUGIN(img->format)) {
         rendererVTableObj *renderer = img->format->vtable;
@@ -1781,7 +1928,7 @@ shapeObj *msOffsetCurve(shapeObj *p, double offset)
     ret->line[i].point=(pointObj*)msSmallMalloc(sizeof(pointObj)*ret->line[i].numpoints);
   }
   for (i = 0; i < p->numlines; i++) {
-    pointObj old_pt, old_diffdir, old_offdir;
+    pointObj old_pt = {0}, old_diffdir, old_offdir;
     if(p->line[i].numpoints<2) {
       ret->line[i].numpoints = 0;
       continue; /* skip degenerate points */
@@ -1954,15 +2101,10 @@ void msCleanup()
   }
   msyylex_destroy();
 
-#ifdef USE_OGR
   msOGRCleanup();
-#endif
-#ifdef USE_GDAL
   msGDALCleanup();
-#endif
 
   /* Release both GDAL and OGR resources */
-#if defined(USE_OGR) || defined(USE_GDAL)
   msAcquireLock( TLOCK_GDAL );
 #if GDAL_VERSION_MAJOR >= 3 || (GDAL_VERSION_MAJOR == 2 && GDAL_VERSION_MINOR == 4)
   /* Cleanup some GDAL global resources in particular */
@@ -1971,15 +2113,17 @@ void msCleanup()
   GDALDestroyDriverManager();
 #endif
   msReleaseLock( TLOCK_GDAL );
-#endif
 
-#ifdef USE_PROJ
+
+#if PROJ_VERSION_MAJOR < 6
 #  if PJ_VERSION >= 480
   pj_clear_initcache();
 #  endif
   pj_deallocate_grids();
-  msSetPROJ_LIB( NULL, NULL );
 #endif
+  msSetPROJ_LIB( NULL, NULL );
+  msProjectionContextPoolCleanup();
+
 #if defined(USE_CURL)
   msHTTPCleanup();
 #endif
@@ -2148,10 +2292,10 @@ void msRGBtoHSL(colorObj *rgb, double *h, double *s, double *l) {
   double r = rgb->red/255.0, g = rgb->green/255.0, b = rgb->blue/255.0;
   double maxv = MS_MAX(MS_MAX(r, g), b), minv = MS_MIN(MS_MIN(r, g), b);
   double d = maxv - minv;
-  
+
   *h = 0, *s = 0;
   *l = (maxv + minv) / 2;
-  
+
   if (maxv != minv)
   {
     *s = *l > 0.5 ? d / (2 - maxv - minv) : d / (maxv + minv);
@@ -2173,11 +2317,11 @@ static double hue_to_rgb(double p, double q, double t) {
 
 void msHSLtoRGB(double h, double s, double l, colorObj *rgb) {
   double r, g, b;
-  
+
   if(s == 0){
     r = g = b = l;
   } else {
-    
+
     double q = l < 0.5 ? l * (1 + s) : l + s - l * s;
     double p = 2 * l - q;
     r = hue_to_rgb(p, q, h + 0.33333333333333333);
@@ -2268,17 +2412,13 @@ void msFreeRasterBuffer(rasterBufferObj *b)
 */
 int msExtentsOverlap(mapObj *map, layerObj *layer)
 {
-#ifdef USE_PROJ
   rectObj map_extent;
   rectObj layer_extent;
-#endif
 
   /* No extent info? Nothing we can do, return MS_UNKNOWN. */
   if( (map->extent.minx == -1) && (map->extent.miny == -1) && (map->extent.maxx == -1 ) && (map->extent.maxy == -1) ) return MS_UNKNOWN;
   if( (layer->extent.minx == -1) && (layer->extent.miny == -1) && (layer->extent.maxx == -1 ) && (layer->extent.maxy == -1) ) return MS_UNKNOWN;
 
-#ifdef USE_PROJ
-
   /* No map projection? Let someone else sort this out. */
   if( ! (map->projection.numargs > 0) )
     return MS_UNKNOWN;
@@ -2316,13 +2456,6 @@ int msExtentsOverlap(mapObj *map, layerObj *layer)
   /* Uh oh, one of the rects crosses the dateline!
   ** Let someone else handle it. */
   return MS_UNKNOWN;
-
-#else
-  /* No proj? Naive comparison. */
-  if( msRectOverlap( &(map->extent), &(layer->extent) ) ) return MS_TRUE;
-  return MS_FALSE;
-#endif
-
 }
 
 /************************************************************************/
@@ -2425,7 +2558,7 @@ char *msBuildOnlineResource(mapObj *map, cgiRequestObj *req)
   port = getenv("HTTP_X_FORWARDED_PORT");
   if(!port)
     port = getenv("SERVER_PORT");
-  
+
   script = getenv("SCRIPT_NAME");
 
   /* HTTPS is set by Apache to "on" in an HTTPS server ... if not set */
@@ -2601,57 +2734,55 @@ void msMapSetLanguageSpecificConnection(mapObj* map, const char* validated_langu
    Ref: http://trac.osgeo.org/gdal/ticket/966 */
 shapeObj* msGeneralize(shapeObj *shape, double tolerance)
 {
-  shapeObj *newShape;
   lineObj newLine = {0,NULL};
-  double sqTolerance = tolerance*tolerance;
-  
-  double dX0, dY0, dX1, dY1, dX, dY, dSqDist;
-  int i;
+  const double sqTolerance = tolerance*tolerance;
 
-  newShape = (shapeObj*)msSmallMalloc(sizeof(shapeObj));
+  shapeObj* newShape = (shapeObj*)msSmallMalloc(sizeof(shapeObj));
   msInitShape(newShape);
   msCopyShape(shape, newShape);
 
   if (shape->numlines<1)
     return newShape;
-  
+
   /* Clean shape */
-  for (i=0; i < newShape->numlines; i++)
+  for (int i=0; i < newShape->numlines; i++)
     free(newShape->line[i].point);
   newShape->numlines = 0;
   if (newShape->line) free(newShape->line);
-    
+
   msAddLine(newShape, &newLine);
-  
-  if (shape->line[0].numpoints>0) {
-    msAddPointToLine(&newShape->line[0],
-                     &shape->line[0].point[0]);              
-    dX0 = shape->line[0].point[0].x;
-    dY0 = shape->line[0].point[0].y;    
+
+  if (shape->line[0].numpoints==0) {
+    return newShape;
   }
-  
-  for(i=1; i<shape->line[0].numpoints; i++)
+
+  msAddPointToLine(&newShape->line[0],
+                   &shape->line[0].point[0]);
+  double dX0 = shape->line[0].point[0].x;
+  double dY0 = shape->line[0].point[0].y;
+
+  for(int i=1; i<shape->line[0].numpoints; i++)
   {
-      dX1 = shape->line[0].point[i].x;
-      dY1 = shape->line[0].point[i].y;
-     
-      dX = dX1-dX0;
-      dY = dY1-dY0;
-      dSqDist = dX*dX + dY*dY;
+      double dX1 = shape->line[0].point[i].x;
+      double dY1 = shape->line[0].point[i].y;
+
+      const double dX = dX1-dX0;
+      const double dY = dY1-dY0;
+      const double dSqDist = dX*dX + dY*dY;
       if (i == shape->line[0].numpoints-1 || dSqDist >= sqTolerance)
       {
           pointObj p;
           p.x = dX1;
           p.y = dY1;
-          
+
           /* Keep this point (always keep the last point) */
           msAddPointToLine(&newShape->line[0],
-                           &p);          
+                           &p);
           dX0 = dX1;
           dY0 = dY1;
         }
     }
-   
+
   return newShape;
 }
 
