@@ -411,7 +411,7 @@ namespace mapserver
                                   Scanline& sl,
                                   ScanlineStorage& storage)
     {
-        int i;
+        unsigned int i;
         const int8u* buf = (const int8u*)bitmap.buffer;
         int pitch = bitmap.pitch;
         sl.reset(x, x + bitmap.width);
@@ -422,12 +422,12 @@ namespace mapserver
             y += bitmap.rows;
             pitch = -pitch;
         }
-        for(i = 0; i < bitmap.rows; i++)
+        for(i = 0; i < (unsigned int)bitmap.rows; i++)
         {
             sl.reset_spans();
             bitset_iterator bits(buf, 0);
-            int j;
-            for(j = 0; j < bitmap.width; j++)
+            unsigned int j;
+            for(j = 0; j < (unsigned int)bitmap.width; j++)
             {
                 if(bits.bit()) sl.add_cell(x + j, cover_full);
                 ++bits;
@@ -452,7 +452,7 @@ namespace mapserver
                                    Scanline& sl,
                                    ScanlineStorage& storage)
     {
-        int i, j;
+        unsigned int i, j;
         const int8u* buf = (const int8u*)bitmap.buffer;
         int pitch = bitmap.pitch;
         sl.reset(x, x + bitmap.width);
@@ -463,11 +463,11 @@ namespace mapserver
             y += bitmap.rows;
             pitch = -pitch;
         }
-        for(i = 0; i < bitmap.rows; i++)
+        for(i = 0; i < (unsigned int)bitmap.rows; i++)
         {
             sl.reset_spans();
             const int8u* p = buf;
-            for(j = 0; j < bitmap.width; j++)
+            for(j = 0; j < (unsigned int)bitmap.width; j++)
             {
                 if(*p) sl.add_cell(x + j, ras.apply_gamma(*p));
                 ++p;
