@@ -22,6 +22,6 @@ apt-get install -q -y git build-essential pkg-config cmake3 libgeos-dev rake \
     libprotobuf-dev libprotobuf-c0-dev protobuf-c-compiler libharfbuzz-dev gdal-bin \
     curl sqlite3
 
-curl https://bootstrap.pypa.io/get-pip.py -o get-pip.py
+curl https://bootstrap.pypa.io/pip/2.7/get-pip.py -o get-pip.py
 python get-pip.py
 pip install -U -r /vagrant/msautotest/requirements.txt
